@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -99,12 +99,13 @@ void gcpBracketsTool::OnDrag ()
 					y0 *= m_dZoomFactor;
 					if (x0 >= xmin && x0 <= xmax && y0 >= ymin && y0 <= ymax) {
 						m_pData->SetSelected (object);
-						gcp::Atom *atom;
+						gcp::Atom *atom = NULL;
 						switch (object->GetType ()) {
 						case gcu::FragmentType:
 							atom = static_cast <gcp::Fragment *> (object)->GetAtom ();
 						case gcu::AtomType: {
-							atom = static_cast <gcp::Atom *> (object);
+							if (atom == NULL)
+								atom = static_cast <gcp::Atom *> (object);
 							// go through the bonds and select them if both ends are selected
 							std::map<gcu::Atom*, gcu::Bond*>::iterator i;
 							gcu::Bond *bond = atom->GetFirstBond (i);
@@ -199,7 +200,7 @@ GtkWidget *gcpBracketsTool::GetPropertyPage ()
 		static bool done = false;
 		if (!done) {
 			done = true;
-			std::string mess = _("Error loading the properties widget description: \n");
+			std::string mess = _("Error loading the properties widget description:\n");
 			mess += e.what ();
 			new gcugtk::Message (GetApplication (), mess, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE);
 		}
